﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Syncfusion.Pdf;
using Syncfusion.Pdf.Parsing;
using Syncfusion.Pdf.Security;
using Syncfusion.Pdf.Graphics;
using System.IO;
using System.Diagnostics;
using System.Drawing;
using Syncfusion.Pdf.Interactive;

namespace DigitalSignatureSample
{
    class Program
    {
        static void Main(string[] args)
        {
            //Load an existing PDF document 
            PdfLoadedDocument loadedDocument = new PdfLoadedDocument("../../Data/Barcode.pdf");

            //Adds a new page
            PdfLoadedPage page = loadedDocument.Pages[0] as PdfLoadedPage;
            PdfGraphics graphics = page.Graphics;

            //Creates a certificate instance from PFX file with the private key
            PdfCertificate pdfCert = new PdfCertificate(@"../../Data/PDF.pfx", "syncfusion");

            //Creates a digital signature
            PdfSignature signature = new PdfSignature(loadedDocument, page, pdfCert, "Signature");

            //Sets signature information
            signature.Bounds = new RectangleF(0, 100, 200, 100);
            signature.ContactInfo = "johndoe@owned.us";
            signature.LocationInfo = "Honolulu, Hawaii";
            signature.Reason = "I am author of this document.";

            signature.EnableValidationAppearance = true;

            //Create appearance for the digital signature
            signature.Appearance.Normal.Graphics.DrawRectangle(PdfBrushes.White, new RectangleF(0, 0, 200, 100));

            //Save the document
            loadedDocument.Save("DigitalSignature.pdf");

            //Close the document
            loadedDocument.Close(true);

            //This will open the PDF file so, the result will be seen in default PDF viewer
            Process.Start("DigitalSignature.pdf");
        }
    }
}
